#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-lib
version:              1.52.1
visibility:           public
id:                   hledger-lib-1.52.1-6vEH2k0AXpc9LX9FAgZx91
key:                  hledger-lib-1.52.1-6vEH2k0AXpc9LX9FAgZx91
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             A library providing the core functionality of hledger
description:
    This library contains hledger'\''s core functionality.
    It is used by most hledger* packages so that they support the same
    command line options, file formats, reports, etc.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting.

    See also:

    - https://hledger.org - hledger'\''s home page

    - https://hledger.org/dev.html - starting point for hledger'\''s developer docs

    - https://hackage.haskell.org/package/hledger-lib/docs/Hledger.html - starting point for hledger'\''s haddock docs

category:             Finance
abi:                  e1281012e9cebb3e9b6ebf188ec8426b
exposed:              True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.BalanceData Hledger.Data.Balancing
    Hledger.Data.Currency Hledger.Data.Dates Hledger.Data.DayPartition
    Hledger.Data.Errors Hledger.Data.Journal Hledger.Data.JournalChecks
    Hledger.Data.JournalChecks.Ordereddates
    Hledger.Data.JournalChecks.Uniqueleafnames Hledger.Data.Json
    Hledger.Data.Ledger Hledger.Data.Period Hledger.Data.PeriodData
    Hledger.Data.PeriodicTransaction Hledger.Data.Posting
    Hledger.Data.RawOptions Hledger.Data.StringFormat
    Hledger.Data.Timeclock Hledger.Data.Transaction
    Hledger.Data.TransactionModifier Hledger.Data.Types
    Hledger.Data.Valuation Hledger.Query Hledger.Read
    Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.InputOptions Hledger.Read.JournalReader
    Hledger.Read.RulesReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.AccountTransactionsReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReport
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Utils Hledger.Utils.Debug
    Hledger.Utils.IO Hledger.Utils.Parse Hledger.Utils.Regex
    Hledger.Utils.String Hledger.Utils.Test Hledger.Utils.Text
    Hledger.Write.Beancount Hledger.Write.Csv Hledger.Write.Html
    Hledger.Write.Html.Attribute Hledger.Write.Html.Blaze
    Hledger.Write.Html.HtmlCommon Hledger.Write.Html.Lucid
    Hledger.Write.Ods Hledger.Write.Spreadsheet Text.Tabular.AsciiWide
    Text.WideString

hidden-modules:       Paths_hledger_lib
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-lib-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-lib-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-lib-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hledger-lib
hs-libraries:         HShledger-lib-1.52.1-6vEH2k0AXpc9LX9FAgZx91
depends:
    Decimal-0.5.2-53XVb6O9fE66SQmvUAIDzC
    Glob-0.10.2-IutOkyaNcwRCJvH1GtzLC7
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    aeson-pretty-0.8.10-4CX5mKtVMfDHxBh4AaJqv5
    ansi-terminal-1.1-BaaOJBYZHtd1MproObBlcZ array-0.5.6.0
    base-4.18.2.1 blaze-html-0.9.2.0-PSPLizehIBK0KyrDun70k
    blaze-markup-0.8.3.0-En1LhSl79346pvouIeUq7J bytestring-0.11.5.3
    call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    cassava-0.5.4.1-KX8phaQMIfMHdPbtRoQSEr
    cassava-megaparsec-2.1.1-44OQt0og3Fs9vD9DPO0YYM
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    colour-2.3.7-IqBe6msxEeC9wavnTrqs50 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 doclayout-0.5.0.1-4yWBv71Y4Kw4DFIRNZ7Kg0
    encoding-0.10.2-7bQKOHSIFPT91FnpaE7HBR
    extra-1.7.16-1gq06OiTdkG7AFSCXWttYR
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    hashtables-1.4.2-Ft6kliYYtetGNkBZGpbG3R
    lucid-2.11.20250303-90P5FC1I18a9HigDcbdN9y
    megaparsec-9.7.0-HsgXVXUZbtJGVbAzhzLwYB
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-Kiwz6ZYAlfY2CJ1USHbUAH mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    pretty-simple-4.1.4.0-HI4xv1bZRmyLER8GdHEa0T process-1.6.19.0
    regex-tdfa-1.3.2.5-8NW0m2HiVCwIy0zxjhdOWx
    safe-0.3.21-GLTVOu0sarW6Z7N465j1G9
    tabular-0.2.2.8-Ly9fepE9sHFB2l1Bgv9bkV
    tasty-1.5.2-9tyUPHiwq7fIOac17jBCXg
    tasty-hunit-0.10.2-1aQPJGmKmQL6O8wlcWrT0t template-haskell-2.20.0.0
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2
    these-1.2.1-IMnyavNhkYt7kp3fydmOsi time-1.12.2
    timeit-2.0-DwmItJuhuSm6aktMh1S1ZM transformers-0.6.1.0
    uglymemo-0.1.0.1-9CTAG7WaUP4YIMm3gIN93
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html:         /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

